==> hasura_connect-2.0.0.tar.gz: test/src/infra/repositories/connector_repository_test.dart <==
import 'package:dartz/dartz.dart';
import 'package:hasura_connect/src/domain/entities/connector.dart';
import 'package:hasura_connect/src/domain/errors/errors.dart';
import 'package:hasura_connect/src/domain/repositories/connector_repository.dart';
import 'package:hasura_connect/src/infra/datasources/connector_datasource.dart';
import 'package:hasura_connect/src/infra/repositories/connector_repository.dart';
import 'package:mockito/mockito.dart';
import 'package:test/test.dart';

class ConnectorDataourceMock extends Mock implements ConnectorDatasource {}

void main() {
  ConnectorDatasource datasource;
  ConnectorRepository repository;
  setUpAll(() {
    datasource = ConnectorDataourceMock();
    repository = ConnectorRepositoryImpl(datasource: datasource);
  });

  test('should return Response', () async {
    when(datasource.websocketConnector(''))
        .thenAnswer((_) async => Connector(null));
    final result = await repository.getConnector('');
    expect(result | null, isA<Connector>());
  });

  test('should return DatasourceError when datasource failed', () async {
    when(datasource.websocketConnector('')).thenThrow(Exception());
    final result = await repository.getConnector('');
    expect(result.fold(id, id), isA<DatasourceError>());
  });

  test('should return error from datasource', () async {
    when(datasource.websocketConnector(''))
        .thenThrow(InvalidRequestError('error'));
    final result = await repository.getConnector('');
    expect(result.fold(id, id), isA<InvalidRequestError>());
  });
}

==> hasura_connect-3.0.4.tar.gz: test/src/infra/repositories/connector_repository_test.dart <==
import 'package:hasura_connect/src/domain/entities/connector.dart';
import 'package:hasura_connect/src/domain/errors/errors.dart';
import 'package:hasura_connect/src/domain/repositories/connector_repository.dart';
import 'package:hasura_connect/src/infra/datasources/connector_datasource.dart';
import 'package:hasura_connect/src/infra/repositories/connector_repository.dart';
import 'package:mocktail/mocktail.dart';
import 'package:test/test.dart';

class ConnectorDataourceMock extends Mock implements ConnectorDatasource {}

void main() {
  late ConnectorDatasource datasource;
  late ConnectorRepository repository;
  setUpAll(() {
    datasource = ConnectorDataourceMock();
    repository = ConnectorRepositoryImpl(datasource: datasource);
  });

  test('should return Response', () async {
    when(datasource).calls(#websocketConnector).thenAnswer((_) async => Connector(Stream.empty()));
    final result = await repository.getConnector('');
    expect(result.right, isA<Connector>());
  });

  test('should return DatasourceError when datasource failed', () async {
    when(datasource).calls(#websocketConnector).thenThrow(Exception());
    final result = await repository.getConnector('');
    expect(result.left, isA<DatasourceError>());
  });

  test('should return error from datasource', () async {
    when(datasource).calls(#websocketConnector).thenThrow(InvalidRequestError('error'));
    final result = await repository.getConnector('');
    expect(result.left, isA<InvalidRequestError>());
  });
}
